@@ -1,8 +1,9 @@
 use strict;
 use warnings;
 package IO::TieCombine::Handle;
-our $VERSION = '1.000';
-
+{
+  $IO::TieCombine::Handle::VERSION = '1.001';
+}
 # ABSTRACT: tied filehandles for IO::TieCombine
 
 use Carp ();
@@ -22,7 +23,8 @@ sub TIEHANDLE {
 sub PRINT {
   my ($self, @output) = @_;
 
-  my $joined = join((defined $, ? $, : ''), @output);
+  my $joined = join((defined $, ? $, : q{}), @output)
+             . (defined $\ ? $\ : q{});
 
   ${ $self->{output_ref}   } .= $joined;
   ${ $self->{combined_ref} } .= $joined;
@@ -43,7 +45,6 @@ sub FILENO   { return 0 + $_[0] }
 1;
 
 __END__
-
 =pod
 
 =head1 NAME
@@ -52,19 +53,18 @@ IO::TieCombine::Handle - tied filehandles for IO::TieCombine
 
 =head1 VERSION
 
-version 1.000
+version 1.001
 
 =head1 AUTHOR
 
-  Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2008 by Ricardo SIGNES.
+This software is copyright (c) 2011 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
-the same terms as perl itself.
-
-=cut 
+the same terms as the Perl 5 programming language system itself.
 
+=cut
 
